function plot_factor_loadings(W, image_size, G, scale)
% plots the factor_loadings produced by MCFA
% plot_factor_loadings(W, image_size, G, scale) 
%   In the resulting plot, each row corresponds to a FA, 
%   and the ith plot in each row corresponds to the ith
%   component of that FA.
%
%   If G is supplied, then it's values are used as a mask
%   when plotting each FA's factor_loadings (i.e. we black-out the 
%   image pixels that the FA hasn't won)
%
% Author: David Ross


%-----------------------------------------------
% Check the input.
%-----------------------------------------------
error(nargchk(1,4,nargin));

[J, K, N] = size(W);

% if no image size has been specified, assume the image
% is square
if nargin == 1 | isempty(image_size)
    img_width = sqrt(N);
    img_height = img_width;
else
    img_height = image_size(1);
    img_width = image_size(2);
end

% do we mask the factor_loadings using G?
if nargin >= 3 & ~isempty(G)
    mask_factor_loadings = 1;
    if ndims(G) == 3
        disp('plot_factor_loadings - averaging G over examples');
        G = mean(G,3);    
    end
else
    mask_factor_loadings = 0;
end

if nargin <= 4
    scale = [-1 1];
end
    
    
%-----------------------------------------------
% Set the figure's properties.
%-----------------------------------------------
%set(gcf, 'NumberTitle', 'off', 'MenuBar', 'none'); 

if mask_factor_loadings
    set(gcf, 'Name', 'Masked Means');
else
    set(gcf, 'Name', 'Means');
end


%-----------------------------------------------
% Plot the factor_loadings.
%-----------------------------------------------
plot_index = 1;

% scale the factor_loadings so that they lie on [0,1]
W = W - min(W(:));
W = W / max(W(:));

% use G to mask the factor_loadings
if mask_factor_loadings
    % a hard mask - plot the weight for a FA only if it 
    % has the largest value for the pixel
    %mask = (G == repmat(max(G')', [1 K]));
    %for j = 1:J
    %    W(j,:,:) = permute(W(j,:,:), [2 3 1]) .* mask';
    %end
    
    % a soft mask
    for j = 1:J
        W(j,:,:) = permute(W(j,:,:), [2 3 1]) .* G';
    end
    
end


for k = 1:K
    my_subplot(K, J+1, plot_index);
    plot_index = plot_index + 1;
    set(gca, 'Visible', 'off');
    text(0, 0.5, sprintf('FA %d', k));
    
    for j = 1:J
        my_subplot(K, J+1, plot_index);
        plot_index = plot_index + 1;
        % imagesc(reshape(W(j,k,:), img_height, img_width));
        img = permute(W(j,k,:), [3 1 2]);
        img = zscore(img);
        imagesc(reshape(img, img_height, img_width),[-3 3]);
        % aa = max(abs(img(:)));
        % imagesc(reshape(img, img_height, img_width), [0 aa]);
        set(gca, 'Visible', 'off');
        colormap('gray');
        axis equal tight;
    end
end
