function plot_results(B, G, M, W, Cost, image_size)
%PLOT_RESULTS plots the model learned by MCVQ
%    plot_results(B, G, M, W, Cost, image_size)
%       Note that this function will plot only the non-empty
%       matricies it it given.  It will work as long as G
%       is not [].
%
%       image_size should specify the width and the height 
%       of the data images.  If the images are square, then
%       image_size can be omitted.
%
%    Author: David Ross

error(nargchk(5,6,nargin));

N = size(G,1); % number of elements in a data vector
K = size(G,2); % number of VQ's

% if no image size has been specified, assume the image 
% is square
if nargin == 5
    image_size = [sqrt(N) sqrt(N)];
end


% plot B, for each VQ
if ~isempty(B)
    figure;
    plot_b(B);
end


% plot M
if ~isempty(M)
    figure;
    plot_m(M);
end


% plot G, for each VQ
if ~isempty(G)
    figure;
    plot_g(G, image_size);
end


% plot W
if ~isempty(W)
    figure;
    plot_weights(W, image_size);
    figure;
    plot_weights(W, image_size, G);
end


% plot the free energies, for each iteration
if ~isempty(Cost)
    figure;
    plot_cost(Cost);
end
